@@ -1,10 +1,12 @@
 import { StoreState } from 'app/types';
 
+import { SAMLConfigState } from './authConfig';
 import { DataSourceCacheState } from './caching';
 import { MetaAnalyticsState } from './metaanalytics';
 import { DataSourcePermissionState } from './permissions';
 import { RecordedQueriesState } from './recordedQuery';
 import { ReportsState } from './reports';
+import { TeamLBACState } from './teamLBAC';
 
 export interface EnterpriseStoreState extends StoreState {
   dataSourcePermission: DataSourcePermissionState;
@@ -12,4 +14,6 @@ export interface EnterpriseStoreState extends StoreState {
   reports: ReportsState;
   metaAnalytics: MetaAnalyticsState;
   recordedQueries: RecordedQueriesState;
+  samlConfig: SAMLConfigState;
+  teamLBAC: TeamLBACState;
 }
