@@ -1,9 +1,9 @@
 import { DataFrame, DataFrameView, Field, FieldCache, FieldType, KeyValue, MutableDataFrame } from '@grafana/data';
-import flatten from 'app/core/utils/flatten';
 
 import { ElasticResponse } from './ElasticResponse';
 import { highlightTags } from './queryDef';
 import { ElasticsearchQuery } from './types';
+import { flattenObject } from './utils';
 
 function getTimeField(frame: DataFrame): Field {
   const field = frame.fields[0];
@@ -315,8 +315,8 @@ describe('ElasticResponse', () => {
       const frame = result.data[0];
       expect(frame.name).toBe('Count');
       expect(frame.length).toBe(2);
-      expect(getTimeField(frame).values.get(0)).toBe(1000);
-      expect(getValueField(frame).values.get(0)).toBe(10);
+      expect(getTimeField(frame).values[0]).toBe(1000);
+      expect(getValueField(frame).values[0]).toBe(10);
     });
   });
 
@@ -367,11 +367,11 @@ describe('ElasticResponse', () => {
       const frame1 = result.data[0];
       const frame2 = result.data[1];
       expect(frame1.length).toBe(2);
-      expect(getValueField(frame1).values.get(0)).toBe(10);
-      expect(getTimeField(frame1).values.get(0)).toBe(1000);
+      expect(getValueField(frame1).values[0]).toBe(10);
+      expect(getTimeField(frame1).values[0]).toBe(1000);
 
       expect(frame2.name).toBe('Average value');
-      expect(getValueField(frame2).values.toArray()).toStrictEqual([88, 99]);
+      expect(getValueField(frame2).values).toEqual([88, 99]);
     });
   });
 
@@ -546,9 +546,9 @@ describe('ElasticResponse', () => {
       expect(result.data[0].length).toBe(2);
       expect(result.data[0].name).toBe('p75 @value');
       expect(result.data[1].name).toBe('p90 @value');
-      expect(getValueField(result.data[0]).values.get(0)).toBe(3.3);
-      expect(getTimeField(result.data[0]).values.get(0)).toBe(1000);
-      expect(getValueField(result.data[1]).values.get(1)).toBe(4.5);
+      expect(getValueField(result.data[0]).values[0]).toBe(3.3);
+      expect(getTimeField(result.data[0]).values[0]).toBe(1000);
+      expect(getValueField(result.data[1]).values[1]).toBe(4.5);
     });
   });
 
@@ -629,8 +629,8 @@ describe('ElasticResponse', () => {
       expect(result.data[0].name).toBe('server1 Max @value');
       expect(result.data[1].name).toBe('server1 Std Dev Upper @value');
 
-      expect(getValueField(result.data[0]).values.get(0)).toBe(10.2);
-      expect(getValueField(result.data[1]).values.get(0)).toBe(3);
+      expect(getValueField(result.data[0]).values[0]).toBe(10.2);
+      expect(getValueField(result.data[1]).values[0]).toBe(3);
     });
   });
 
@@ -688,20 +688,20 @@ describe('ElasticResponse', () => {
       const firstSeries = result.data[0];
       expect(firstSeries.name).toBe('Top Metrics @value');
       expect(firstSeries.length).toBe(2);
-      expect(getTimeField(firstSeries).values.toArray()).toStrictEqual([
+      expect(getTimeField(firstSeries).values).toEqual([
         new Date('2021-01-01T00:00:00.000Z').valueOf(),
         new Date('2021-01-01T00:00:10.000Z').valueOf(),
       ]);
-      expect(getValueField(firstSeries).values.toArray()).toStrictEqual([1, 1]);
+      expect(getValueField(firstSeries).values).toEqual([1, 1]);
 
       const secondSeries = result.data[1];
       expect(secondSeries.name).toBe('Top Metrics @anotherValue');
       expect(secondSeries.length).toBe(2);
-      expect(getTimeField(secondSeries).values.toArray()).toStrictEqual([
+      expect(getTimeField(secondSeries).values).toEqual([
         new Date('2021-01-01T00:00:00.000Z').valueOf(),
         new Date('2021-01-01T00:00:10.000Z').valueOf(),
       ]);
-      expect(getValueField(secondSeries).values.toArray()).toStrictEqual([2, 2]);
+      expect(getValueField(secondSeries).values).toEqual([2, 2]);
     });
   });
 
@@ -814,9 +814,9 @@ describe('ElasticResponse', () => {
       const { fields } = result.data[0];
       expect(fields.length).toBe(2);
       expect(fields[0].name).toBe('bytes');
-      expect(fields[0].config).toStrictEqual({ filterable: true });
+      expect(fields[0].config).toEqual({ filterable: true });
       expect(fields[1].name).toBe('Count');
-      expect(fields[1].config).toStrictEqual({});
+      expect(fields[1].config).toEqual({});
     });
   });
 
@@ -989,9 +989,9 @@ describe('ElasticResponse', () => {
       const field2 = result.data[0].fields[1];
       const field3 = result.data[0].fields[2];
 
-      expect(field1.values.toArray()).toStrictEqual(['server-1', 'server-2']);
-      expect(field2.values.toArray()).toStrictEqual([1000, 2000]);
-      expect(field3.values.toArray()).toStrictEqual([369, 200]);
+      expect(field1.values).toEqual(['server-1', 'server-2']);
+      expect(field2.values).toEqual([1000, 2000]);
+      expect(field3.values).toEqual([369, 200]);
     });
   });
 
@@ -1044,9 +1044,9 @@ describe('ElasticResponse', () => {
       expect(field2.name).toBe('p75 value');
       expect(field3.name).toBe('p90 value');
 
-      expect(field1.values.toArray()).toStrictEqual(['id1', 'id2']);
-      expect(field2.values.toArray()).toStrictEqual([3.3, 2.3]);
-      expect(field3.values.toArray()).toStrictEqual([5.5, 4.5]);
+      expect(field1.values).toEqual(['id1', 'id2']);
+      expect(field2.values).toEqual([3.3, 2.3]);
+      expect(field3.values).toEqual([5.5, 4.5]);
     });
   });
 
@@ -1088,9 +1088,9 @@ describe('ElasticResponse', () => {
     it('should include field in metric name', () => {
       expect(result.data[0].length).toBe(1);
       expect(result.data[0].fields.length).toBe(3);
-      expect(result.data[0].fields[0].values.toArray()).toStrictEqual(['server-1']);
-      expect(result.data[0].fields[1].values.toArray()).toStrictEqual([1000]);
-      expect(result.data[0].fields[2].values.toArray()).toStrictEqual([3000]);
+      expect(result.data[0].fields[0].values).toEqual(['server-1']);
+      expect(result.data[0].fields[1].values).toEqual([1000]);
+      expect(result.data[0].fields[2].values).toEqual([3000]);
     });
   });
 
@@ -1139,7 +1139,7 @@ describe('ElasticResponse', () => {
       expect(fields.length).toBe(1);
       const field = fields[0];
       expect(field.type === FieldType.other);
-      const values = field.values.toArray();
+      const values = field.values;
       expect(values.length).toBe(2);
       expect(values[0].sourceProp).toBe('asd');
       expect(values[0].fieldProp).toBe('field');
@@ -1206,12 +1206,12 @@ describe('ElasticResponse', () => {
       expect(result.data[0].name).toBe('Sum @value');
       expect(result.data[1].name).toBe('Max @value');
       expect(result.data[2].name).toBe('Sum @value * Max @value');
-      expect(getValueField(result.data[0]).values.get(0)).toBe(2);
-      expect(getValueField(result.data[1]).values.get(0)).toBe(3);
-      expect(getValueField(result.data[2]).values.get(0)).toBe(6);
-      expect(getValueField(result.data[0]).values.get(1)).toBe(3);
-      expect(getValueField(result.data[1]).values.get(1)).toBe(4);
-      expect(getValueField(result.data[2]).values.get(1)).toBe(12);
+      expect(getValueField(result.data[0]).values[0]).toBe(2);
+      expect(getValueField(result.data[1]).values[0]).toBe(3);
+      expect(getValueField(result.data[2]).values[0]).toBe(6);
+      expect(getValueField(result.data[0]).values[1]).toBe(3);
+      expect(getValueField(result.data[1]).values[1]).toBe(4);
+      expect(getValueField(result.data[2]).values[1]).toBe(12);
     });
   });
 
@@ -1286,11 +1286,11 @@ describe('ElasticResponse', () => {
       expect(frame.length).toBe(2);
       const { fields } = frame;
       expect(fields.length).toBe(5);
-      expect(fields[0].values.toArray()).toStrictEqual([1000, 2000]);
-      expect(fields[1].values.toArray()).toStrictEqual([2, 3]);
-      expect(fields[2].values.toArray()).toStrictEqual([3, 4]);
-      expect(fields[3].values.toArray()).toStrictEqual([6, 12]);
-      expect(fields[4].values.toArray()).toStrictEqual([24, 48]);
+      expect(fields[0].values).toEqual([1000, 2000]);
+      expect(fields[1].values).toEqual([2, 3]);
+      expect(fields[2].values).toEqual([3, 4]);
+      expect(fields[3].values).toEqual([6, 12]);
+      expect(fields[4].values).toEqual([24, 48]);
     });
   });
 
@@ -1301,6 +1301,7 @@ describe('ElasticResponse', () => {
           refId: 'A',
           metrics: [{ type: 'raw_data', id: '1' }],
           bucketAggs: [],
+          timeField: '@timestamp',
         },
       ];
 
@@ -1317,7 +1318,7 @@ describe('ElasticResponse', () => {
                   _id: '1',
                   _type: '_doc',
                   _index: 'index',
-                  _source: { sourceProp: 'asd' },
+                  _source: { sourceProp: 'asd', '@timestamp': '2019-01-01T00:00:00Z' },
                 },
               ],
             },
@@ -1333,6 +1334,12 @@ describe('ElasticResponse', () => {
         expect(field.config.filterable).toBe(true);
       }
     });
+
+    it('should have time field values in DateTime format', () => {
+      const timeField = result.data[0].fields.find((field) => field.name === '@timestamp');
+      expect(timeField).toBeDefined();
+      expect(timeField?.values[0]).toBe(1546300800000);
+    });
   });
 
   describe('simple logs query and count', () => {
@@ -1438,7 +1445,7 @@ describe('ElasticResponse', () => {
         expect(r._id).toEqual(response.responses[0].hits.hits[i]._id);
         expect(r._type).toEqual(response.responses[0].hits.hits[i]._type);
         expect(r._index).toEqual(response.responses[0].hits.hits[i]._index);
-        expect(r._source).toEqual(flatten(response.responses[0].hits.hits[i]._source));
+        expect(r._source).toEqual(flattenObject(response.responses[0].hits.hits[i]._source));
       }
 
       // Make a map from the histogram results
@@ -1460,14 +1467,14 @@ describe('ElasticResponse', () => {
       const result = new ElasticResponse(targets, response).getLogs(undefined, 'level');
       const fieldCache = new FieldCache(result.data[0]);
       const field = fieldCache.getFieldByName('level');
-      expect(field?.values.toArray()).toEqual(['debug', 'error']);
+      expect(field?.values).toEqual(['debug', 'error']);
     });
 
     it('should re map levels field to new field', () => {
       const result = new ElasticResponse(targets, response).getLogs(undefined, 'fields.lvl');
       const fieldCache = new FieldCache(result.data[0]);
       const field = fieldCache.getFieldByName('level');
-      expect(field?.values.toArray()).toEqual(['debug', 'info']);
+      expect(field?.values).toEqual(['debug', 'info']);
     });
 
     it('should correctly guess field types', () => {
